@@ -4,8 +4,6 @@ import System.IO
 import System.Exit (die)
 
 import Hasql.Connection
-import Hasql.Connection.Setting
-import Hasql.Connection.Setting.Connection
 import Hasql.Notifications
 
 main :: IO ()
@@ -13,7 +11,7 @@ main = do
     hSetBuffering stdout NoBuffering
     hSetBuffering stderr NoBuffering
 
-    dbOrError <- acquire [ connection $ string "postgres://localhost/db_name" ]
+    dbOrError <- acquire "postgres://localhost/db_name"
     case dbOrError of
         Right db -> do
             let channelToListen = toPgIdentifier "sample-channel"
